#include <rtt/Logger.hpp>

#include "ComponentA.hpp"

namespace Test
{ 

ComponentA::ComponentA(std::string name) : 
  RTT::TaskContext(name),
  // ports
  m_bar_port("bar"),
  // properties
  m_a_string("AString", "A string", "/dev/a"),
  m_an_unsigned("AnUnsigned", "An unsigned", 42)
{
  RTT::Logger::In in(__PRETTY_FUNCTION__);
  RTT::Logger::log( RTT::Logger::Debug ) << "enter" << RTT::Logger::endl;
  // ports
  this->ports()->addPort( &m_bar_port );
  // properties
  this->properties()->addProperty( &m_a_string );
  this->properties()->addProperty( &m_an_unsigned );
  RTT::Logger::log( RTT::Logger::Debug ) << "exit" << RTT::Logger::endl;
}
  
/**
 * This function is for the configuration code.
 * Return false to abort configuration.
 */
bool ComponentA::configureHook() 
{
  RTT::Logger::In in(__PRETTY_FUNCTION__);
  RTT::Logger::log( RTT::Logger::Debug ) << "enter" << RTT::Logger::endl;
  RTT::Logger::log( RTT::Logger::Debug ) << "exit" << RTT::Logger::endl;
  return true;
}

/**
 * This function is for the application's start up code.
 * Return false to abort start up.
 */
bool ComponentA::startHook() 
{
  RTT::Logger::In in(__PRETTY_FUNCTION__);
  RTT::Logger::log( RTT::Logger::Debug ) << "enter" << RTT::Logger::endl;
  m_bar.m_flag = true;
  RTT::Logger::log( RTT::Logger::Debug ) << "exit" << RTT::Logger::endl;
  return true;
}

/**
 * This function is called by the Execution Engine.
 */
void ComponentA::updateHook() 
{
  RTT::Logger::In in(__PRETTY_FUNCTION__);
  RTT::Logger::log( RTT::Logger::Debug ) << "enter" << RTT::Logger::endl;
  m_bar_port.Set(m_bar);
  RTT::Logger::log( RTT::Logger::Debug ) << "exit" << RTT::Logger::endl;
}

/**
 * This function is called when the task is stopped.
 */
void ComponentA::stopHook() 
{
  RTT::Logger::Logger::In in(__PRETTY_FUNCTION__);
  RTT::Logger::log( RTT::Logger::Debug ) << "enter" << RTT::Logger::endl;
  RTT::Logger::log( RTT::Logger::Debug ) << "exit" << RTT::Logger::endl;
}

/**
 * This function is called when the task is being deconfigured.
 */
void ComponentA::cleanupHook() 
{
  RTT::Logger::Logger::In in(__PRETTY_FUNCTION__);
  RTT::Logger::log( RTT::Logger::Debug ) << "enter" << RTT::Logger::endl;
  RTT::Logger::log( RTT::Logger::Debug ) << "exit" << RTT::Logger::endl;
}

}

#include <ocl/ComponentLoader.hpp>
ORO_LIST_COMPONENT_TYPE(Test::ComponentA)

